--- althea-ssl-0.5.5.orig/MIME.cpp
+++ althea-ssl-0.5.5/MIME.cpp
@@ -91,7 +91,7 @@
 }
 
 void check(unsigned int convertedVal, ifstream &fileIn, int loc, int counter)  {
-   unsigned char c;
+   char c;
 
    fileIn.get(c);
    if ((unsigned int)c!=convertedVal)  {
--- althea-ssl-0.5.5.orig/MIME.h
+++ althea-ssl-0.5.5/MIME.h
@@ -1,5 +1,7 @@
 #ifndef MIME_H
 #define MIME_H
+namespace std {};
+using namespace std;
 
 
 #include <string>
--- althea-ssl-0.5.5.orig/Makefile
+++ althea-ssl-0.5.5/Makefile
@@ -1,3 +1,20 @@
+# Modified for Debian by Jimmy Kaplowitz <jimmy@kaplowitz.org> at:
+# Sat, 21 Apr 2001 21:30:40 -0400
+#
+# Note - I have changed the meaning of ${DESTDIR} to refer to the destination
+# prefix and not the bin dir. Also, people familiar with Debian packages
+# should note that ${DESTDIR} here is like the --prefix option to configure;
+# the make install will install into ${INSTALLROOT} instead.
+#
+# Hopefully these changes will make it into the upstream distribution so that
+# they don't have to be reapplied for each release; they shouldn't break
+# anything on non-Debian systems, and the only changes that will be noticed is
+# that the althea binary and the documentation are moved to /usr/X11R6/bin and
+# /usr/share/doc/althea, respectively.
+#
+# Update on 13 Jun 2001 - the binary has been moved back to /usr/bin as per
+# Debian Policy section 12.8.7.
+
 #Changes to make compile possible on Suns and BSD boxen thanks to Thomas Strmberg
 
 
@@ -51,9 +68,11 @@
 DEBUGFLAGS = -Wall -ftemplate-depth-30 -g ${NOSSLFLAG}
 LDADD = `gtk-config --libs` ${LDFLAGS}
 
-DESTDIR = /usr/local/bin
-PIXDIR = /usr/local/share/althea
-DOCDIR = /usr/local/doc/althea
+DESTDIR = /usr
+
+BINDIR = ${DESTDIR}/bin
+PIXDIR = ${DESTDIR}/share/althea-ssl
+DOCDIR = ${DESTDIR}/doc/althea-ssl
 
 all : ${OBJS} 
 	g++ ${DEBUGFLAGS} ${SSLFLAGS} -o althea main.cpp -DPIXDIR=\"${PIXDIR}\" ${OBJS} ${CFLAGS} ${LDADD}
@@ -150,26 +169,26 @@
 helpDialog.o : helpDialog.cpp helpDialog.h
 	g++ ${DEBUGFLAGS} -c helpDialog.cpp -DDOCDIR=\"${DOCDIR}\" ${CFLAGS}
 
-${DESTDIR} :
-	mkdir -p ${DESTDIR}
+${INSTALLROOT}${BINDIR} :
+	mkdir -p ${INSTALLROOT}${BINDIR}
 
-${DOCDIR} :
-	mkdir -p ${DOCDIR}
+${INSTALLROOT}${DOCDIR} :
+	mkdir -p ${INSTALLROOT}${DOCDIR}
 
-${PIXDIR} :
-	mkdir -p ${PIXDIR}
+${INSTALLROOT}${PIXDIR} :
+	mkdir -p ${INSTALLROOT}${PIXDIR}
 
-install : althea pixmaps Documentation ${DESTDIR}  ${PIXDIR}
-	cp ./althea ${DESTDIR}
-	cp -r Documentation/* ${DOCDIR}
-	cp -r pixmaps/* ${PIXDIR}
+install : althea pixmaps Documentation ${INSTALLROOT}${BINDIR} ${INSTALLROOT}${DOCDIR} ${INSTALLROOT}${PIXDIR}
+	cp ./althea ${INSTALLROOT}${BINDIR}
+	cp -r Documentation/* ${INSTALLROOT}${DOCDIR}
+	cp -r pixmaps/* ${INSTALLROOT}${PIXDIR}
 
 uninstall: 
-	rm -f ${DESTDIR}/althea
-	rm -rf ${DOCDIR}/*
-	rmdir ${DOCDIR}
-	rm -rf ${PIXDIR}/*
-	rmdir ${PIXDIR}
+	rm -f ${INSTALLROOT}${BINDIR}/althea
+	rm -rf ${INSTALLROOT}${DOCDIR}/*
+	rmdir ${INSTALLROOT}${DOCDIR}
+	rm -rf ${INSTALLROOT}${PIXDIR}/*
+	rmdir ${INSTALLROOT}${PIXDIR}
 
 clean :
 	rm -f althea
--- althea-ssl-0.5.5.orig/SelectFolder.cpp
+++ althea-ssl-0.5.5/SelectFolder.cpp
@@ -323,7 +323,7 @@
 
    
   // compose our command
-  command = "aHEADER uid FETCH 1:4294967296 (BODY.PEEK[header] FLAGS BODYSTRUCTURE)\r\n";
+  command = "aHEADER uid FETCH 1:4294967295 (BODY.PEEK[header] FLAGS BODYSTRUCTURE)\r\n";
    
   /********************************************
    * get all of our header information from   *
@@ -508,7 +508,7 @@
 	nextuid=1;
 
        
-      command = "aHEADER uid FETCH " + itoa(nextuid) + ":4294967296 BODY.PEEK[header]\r\n";
+      command = "aHEADER uid FETCH " + itoa(nextuid) + ":4294967295 BODY.PEEK[header]\r\n";
 
       /********************************************
        * get all of our header information from   *
--- althea-ssl-0.5.5.orig/tolower.h
+++ althea-ssl-0.5.5/tolower.h
@@ -1,5 +1,7 @@
 #ifndef TOLOWER_H
 #define TOLOWER_H
+namespace std {};
+using namespace std;
 
 #include <iostream>
 #include <string>
--- althea-ssl-0.5.5.orig/debian/althea.1
+++ althea-ssl-0.5.5/debian/althea.1
@@ -0,0 +1,40 @@
+.\" Hey, EMACS: -*- nroff -*-
+.\" First parameter, NAME, should be all caps
+.\" Second parameter, SECTION, should be 1-8, maybe w/ subsection
+.\" other parameters are allowed: see man(7), man(1)
+.\" Please adjust this date whenever revising the manpage.
+.\" 
+.\" Some roff macros, for reference:
+.\" .nh        disable hyphenation
+.\" .hy        enable hyphenation
+.\" .ad l      left justify
+.\" .ad b      justify to both left and right margins
+.\" .nf        disable filling
+.\" .fi        enable filling
+.\" .br        insert line break
+.\" .sp <n>    insert n+1 empty lines
+.\" for manpage-specific macros, see man(7)
+.TH "ALTHEA" "1" "April 21, 2001" "" ""
+.SH "NAME"
+althea \- IMAP email client for GTK+
+.SH "SYNOPSIS"
+.B althea
+.SH "DESCRIPTION"
+The designers of Althea felt that there wasn't a stable, easy to use,
+GUI, IMAP (Internet Message Access Protocol) e\-mail client for X
+Windows. The design goal was a stable e\-mail client with the richness
+of usability of Microsoft's Outlook, Qualcomm's Eudora, and Cyrusoft's
+Mulberry.
+.PP 
+This manual page was written for the Debian GNU/Linux distribution because
+.B althea
+does not have a manual page.
+Instead, it has documentation in HTML format, of which the
+preceding paragraph is an excerpt; see below.
+.SH "SEE ALSO"
+This program is documented by the HTML file
+.I /usr/doc/althea-ssl/help.html
+.
+.SH "AUTHOR"
+This manual page was written by Jimmy Kaplowitz <jimmy@debian.org>,
+for the Debian GNU/Linux system (but may be used by others).
--- althea-ssl-0.5.5.orig/debian/menu
+++ althea-ssl-0.5.5/debian/menu
@@ -0,0 +1,2 @@
+?package(althea-ssl):needs=X11 section=Apps/Net\
+  title="Althea" command="/usr/bin/althea"
--- althea-ssl-0.5.5.orig/debian/changelog
+++ althea-ssl-0.5.5/debian/changelog
@@ -0,0 +1,155 @@
+althea-ssl (0.5.5-2) unstable; urgency=low
+
+  * Auto-generated from the respective althea package
+  * Fixed compilation with g++ 3.0 (#121150, #121152)
+
+ -- Jimmy Kaplowitz <jimmy@debian.org>  Sun, 25 Nov 2001 21:37:49 -0500
+
+althea (0.5.5-1) unstable; urgency=low
+
+  * New upstream release
+  * Patched SelectFolder.cpp to fix hanging when retrieving message
+    headers
+
+ -- Jimmy Kaplowitz <jimmy@debian.org>  Sat, 10 Nov 2001 01:24:09 -0500
+
+althea (0.5.4-1) unstable; urgency=low
+
+  * New upstream release
+  * Three bugs were fixed in the 0.5.3-1 release, which was not
+    uploaded due to excessive upstream bugginess. (#99853,
+    #101721, #102491)
+
+ -- Jimmy Kaplowitz <jimmy@debian.org>  Mon, 24 Sep 2001 22:19:06 -0400
+
+althea (0.5.3-1) unstable; urgency=low
+
+  * New upstream release (#99853, #101721, #102491)
+  * May have fixed problem with .orig.tar.gz files for althea-ssl being
+    regenerated with every new Debian release
+
+ -- Jimmy Kaplowitz <jimmy@debian.org>  Fri, 20 Jul 2001 14:29:27 -0400
+
+althea (0.5.2-4) unstable; urgency=low
+
+  * Fixed g++ 3.0 compilation error which was preventing builds on hppa.
+    This is already fixed in CVS. (#104897, #104959)
+
+ -- Jimmy Kaplowitz <jimmy@debian.org>  Sat, 14 Jul 2001 11:02:09 -0400
+
+althea (0.5.2-3) unstable; urgency=low
+
+  * Changed man page author email address to be jimmy@debian.org
+  * Updated Standards-Version to 3.5.5; 0.5.2-2 was the first release
+    compliant with this version of Policy.
+
+ -- Jimmy Kaplowitz <jimmy@debian.org>  Sat, 14 Jul 2001 00:06:43 -0400
+
+althea (0.5.2-2) unstable; urgency=low
+
+  * Moved binary from /usr/X11R6/bin/althea to /usr/bin/althea and man
+    page from /usr/X11R6/man/man1/althea.1x.gz to
+    /usr/share/man/man1/althea.1.gz as per Debian Policy section 12.8.7
+  * Fixed some references to /usr/share/doc/althea to point to
+    /usr/share/doc/althea-ssl in the althea-ssl package
+
+ -- Jimmy Kaplowitz <jimmy@debian.org>  Fri, 13 Jul 2001 23:43:12 -0400
+
+althea (0.5.2-1) unstable; urgency=low
+
+  * New upstream release
+  * Fixed some inappropriate permissions that lintian just started to
+    complain about
+  * Changed the select-ssl target in debian/rules so that the previous
+    althea-ssl-V.E.R tree is wiped out
+  * Changed debian/rules so that the .orig.tar.gz for althea-ssl
+    extracts into althea-ssl_V.E.R.orig rather than althea_V.E.R.orig
+
+ -- Jimmy Kaplowitz <jimmy@debian.org>  Sat,  9 Jun 2001 18:07:19 -0400
+
+althea (0.5.1-4) unstable; urgency=low
+
+  * Fixed Makefile to compile properly without libssl-dev installed
+
+ -- Jimmy Kaplowitz <jimmy@debian.org>  Fri,  8 Jun 2001 17:07:47 -0400
+
+althea (0.5.1-3) unstable; urgency=low
+
+  * Added Replaces: althea and Conflicts: althea in the althea-ssl control file
+
+ -- Jimmy Kaplowitz <jimmy@debian.org>  Tue,  5 Jun 2001 12:04:23 -0400
+
+althea (0.5.1-2) unstable; urgency=low
+
+  * Moved althea back into the mail section of main, disabled support
+    for SSL, and added an automatically generated althea-ssl package in
+    non-US with SSL support
+  * Put althearc.example from the source distribution into the generated
+    .deb as an example file
+  * Moved handling of DEB_BUILD_OPTIONS=debug to debian/rules, and added
+    a MORE_CFLAGS flag to Makefile which is used in debian/rules
+
+ -- Jimmy Kaplowitz <jimmy@debian.org>  Tue,  5 Jun 2001 11:07:36 -0400
+
+althea (0.5.1-1) unstable; urgency=low
+
+  * New upstream release
+  * Changed debian/watch back to using uupdate instead of uupdate -u.
+    The -u wasn't getting added in the uupdate command as generated by
+    uscan, anyway.
+  * Moved althea to non-US and added a Build-Depends on libssl-dev, due
+    to the SSL support added in version 0.5.0.
+  * Added instructions for disabling SSL support to README.Debian, and
+    mentioned SSL support in the package description
+  * Changed maintainer email to jimmy@debian.org in order to reflect
+    newly acquired official Debian developer status
+
+ -- Jimmy Kaplowitz <jimmy@debian.org>  Mon, 21 May 2001 21:53:28 -0400
+
+althea (0.4.4a-1) unstable; urgency=low
+
+  * New upstream release
+  * Changed debian/watch to use uupdate -u rather than uupdate
+  * Changed some files in debian/ to point out that they are no longer
+    examples, though they are derived from examples
+
+ -- Jimmy Kaplowitz <jimmy@kaplowitz.org>  Mon,  7 May 2001 21:49:00 -0400
+
+althea (0.4.3-1) unstable; urgency=low
+
+  * New upstream release
+
+ -- Jimmy Kaplowitz <jimmy@kaplowitz.org>  Fri,  4 May 2001 15:31:01 -0400
+
+althea (0.4.2-1) unstable; urgency=low
+
+  * New upstream release
+
+ -- Jimmy Kaplowitz <jimmy@kaplowitz.org>  Wed,  2 May 2001 21:38:32 -0400
+
+althea (0.4.1-3) unstable; urgency=low
+
+  * Changed section to mail
+  * Added provide for imap-client virtual staff
+  * Added upstream changelog to the generated package
+
+ -- Jimmy Kaplowitz <jimmy@kaplowitz.org>  Thu, 26 Apr 2001 19:39:18 -0400
+
+althea (0.4.1-2) unstable; urgency=low
+
+  * Added support for DEB_BUILD_OPTIONS=debug as per Policy 11.1
+  * Removed CVS directories from generated .deb files
+
+ -- Jimmy Kaplowitz <jimmy@kaplowitz.org>  Sun, 22 Apr 2001 21:01:34 -0400
+
+althea (0.4.1-1) unstable; urgency=low
+
+  * Initial release. (#91842)
+  * This is my first Debian package. If anything is wrong, please let me know.
+  * Radically modified the Makefile to facilitate building .deb packages.
+
+ -- Jimmy Kaplowitz <jimmy@kaplowitz.org>  Sat, 21 Apr 2001 21:28:55 -0400
+
+Local variables:
+mode: debian-changelog
+End:
--- althea-ssl-0.5.5.orig/debian/rules
+++ althea-ssl-0.5.5/debian/rules
@@ -0,0 +1,158 @@
+#!/usr/bin/make -f
+# althea and althea-ssl rules file
+# By Jimmy Kaplowitz <jimmy@debian.org>
+# GNU copyright 2001 by Jimmy Kaplowitz.
+# Derived from the sample debian/rules that uses debhelper, which is
+# GNU copyright 1997 to 1999 by Joey Hess.
+# Also contains some code from the fetchmail and fetchmail-ssl rules file,
+# which is by Henrique M. Holschuh <hmh@debian.org> and is itself a derivative
+# work.
+
+# To generate the SSL package, run the select-ssl target. This will clean your
+# source tree and then create a new directory tree parallel to this one called
+# althea-ssl-V.E.R/ (where V.E.R is the current version), wiping out any
+# existing such tree. It DOES NOT change the current directory; keep this in
+# mind when building the ssl version. The select-ssl target requires the patch
+# program, available in the patch package, to be installed. The patch program
+# is not listed in the Build-Depends: line because this package can be built
+# without it.
+#
+# Because it calls the clean target, the select-ssl target must be run as root
+# (or with fakeroot).
+
+# Uncomment this to turn on verbose mode.
+#export DH_VERBOSE=1
+
+# This is the debhelper compatability version to use.
+export DH_COMPAT=3
+
+package=althea-ssl
+version=$(shell pwd | sed -e 's@.*/althea-\([0-9][^/]*\)@\1@')
+
+configure: configure-stamp
+configure-stamp:
+	dh_testdir
+	# Add here commands to configure the package.
+	
+
+	touch configure-stamp
+
+build: configure-stamp build-stamp
+build-stamp:
+	dh_testdir
+
+	# Add here commands to compile the package.
+ifneq (,$(findstring debug,$(DEB_BUILD_OPTIONS)))
+	$(MAKE) MORE_CFLAGS=-g
+else
+	$(MAKE)
+endif
+	#/usr/bin/docbook-to-man debian/althea.sgml > althea.1
+
+	touch build-stamp
+
+clean:
+	dh_testdir
+	dh_testroot
+	rm -f build-stamp configure-stamp Makefile~
+
+	# Add here commands to clean up after the build process.
+	-$(MAKE) clean
+
+	dh_clean
+
+install: build
+	dh_testdir
+	dh_testroot
+	dh_clean -k
+	dh_installdirs
+
+	# Add here commands to install the package into debian/$(package).
+	$(MAKE) install INSTALLROOT=$(CURDIR)/debian/$(package)
+
+
+# Build architecture-independent files here.
+binary-indep: build install
+# We have nothing to do by default.
+
+# Build architecture-dependent files here.
+binary-arch: build install
+	dh_testdir
+	dh_testroot
+#	dh_installdebconf	
+	dh_installdocs
+	dh_installexamples althearc.example
+	dh_installmenu
+#	dh_installlogrotate
+#	dh_installemacsen
+#	dh_installpam
+#	dh_installmime
+#	dh_installinit
+#	dh_installcron
+	dh_installman
+#	dh_installinfo
+#	dh_undocumented
+	dh_installchangelogs changelog
+#	dh_link
+	dh_strip
+	dh_compress
+	dh_fixperms
+	# dh_fixperms doesn't do this
+	find $(CURDIR)/debian/$(package)/usr/share/$(package) \
+	  \! -type d -exec chmod -x {} \;
+	find $(CURDIR)/debian/$(package)/usr/doc/$(package)/examples \
+	  \! -type d -exec chmod -x {} \;
+#	dh_makeshlibs
+	dh_installdeb
+#	dh_perl
+	dh_shlibdeps
+	dh_gencontrol
+	dh_md5sums
+	dh_builddeb
+
+binary: binary-indep binary-arch
+
+#
+# Do not run the target below unless you know what you're doing. See above.
+#
+select-ssl: clean
+ifeq (,$(findstring ssl,$(package)))
+	dh_testdir
+	(cd .. ;\
+	rm -rf althea-ssl-$(version) ;\
+	cp -a althea-$(version) althea-ssl-$(version) ;\
+	if ! [ -f althea-ssl_$(version).orig.tar.gz ] ; then\
+	tar -xzf althea_$(version).orig.tar.gz ;\
+	mv althea-$(version).orig althea-ssl-$(version).orig ;\
+	tar -czf althea-ssl_$(version).orig.tar.gz althea-ssl-$(version).orig ;\
+	rm -rf althea-ssl-$(version).orig ;\
+	fi \
+	)
+	(cd ../althea-ssl-$(version)/debian ;\
+	sed -e 's/package=althea-ssl/package=althea-ssl/' <rules >rules.new ;\
+	sed -e '1 s/althea (/althea-ssl (/' \
+	  -e '2p' \
+	  -e '2s/.*/  * Auto-generated from the respective althea package/'\
+	  -e 's/closes:\ \+#/#/Ig' <changelog >>changelog.new; \
+	sed -e 's/package(althea/package(althea-ssl/' < menu > menu.new ;\
+	sed -e 's@/usr/doc/althea/@/usr/doc/althea-ssl/@' \
+	  < doc-base > doc-base.new ;\
+	sed -e 's@/usr/doc/althea/@/usr/doc/althea-ssl/@' \
+	  < althea.1 > althea.1.new ;\
+	cd .. ;\
+	patch < debian/enable-ssl-in-Makefile-patch ;\
+	cd debian ;\
+	mv -f control control.no-ssl ;\
+	mv -f control.with-ssl control ;\
+	mv -f menu.new menu ;\
+	mv -f doc-base.new doc-base ;\
+	mv -f althea.1.new althea.1 ;\
+	mv -f changelog.new changelog ;\
+	mv -f rules.new rules ;\
+	chmod +x rules \
+	)
+else
+	echo "This package already has SSL support enabled!"
+endif
+
+.PHONY: build clean binary-indep binary-arch binary install configure select-ssl
--- althea-ssl-0.5.5.orig/debian/control
+++ althea-ssl-0.5.5/debian/control
@@ -0,0 +1,25 @@
+Source: althea-ssl
+Section: non-US
+Priority: optional
+Maintainer: Jimmy Kaplowitz <jimmy@debian.org>
+Build-Depends: libglib1.2-dev (>= 1.2.0), libgtk1.2-dev (>= 1.2.0), debhelper (>> 3.0.0), libssl-dev
+Standards-Version: 3.5.6
+
+Package: althea-ssl
+Architecture: any
+Depends: ${shlibs:Depends}
+Provides: imap-client
+Replaces: althea
+Conflicts: althea
+Description: IMAP email client for GTK+
+ The designers of Althea felt that there wasn't a stable, easy to use,
+ GUI, IMAP (Internet Message Access Protocol) e-mail client for X
+ Windows. The design goal was a stable e-mail client with the richness
+ of usability of Microsoft's Outlook, Qualcomm's Eudora, and Cyrusoft's
+ Mulberry.
+ .
+ This package was built with SSL support. If you want a package without
+ SSL support, download the althea package in the mail section of main.
+ .
+ Check the documentation at /usr/share/doc/althea-ssl/help.html before filing
+ a bug report.
--- althea-ssl-0.5.5.orig/debian/manpages
+++ althea-ssl-0.5.5/debian/manpages
@@ -0,0 +1 @@
+debian/althea.1
--- althea-ssl-0.5.5.orig/debian/postinst
+++ althea-ssl-0.5.5/debian/postinst
@@ -0,0 +1,47 @@
+#! /bin/sh
+# postinst script for althea
+#
+# see: dh_installdeb(1)
+
+set -e
+
+# summary of how this script can be called:
+#        * <postinst> `configure' <most-recently-configured-version>
+#        * <old-postinst> `abort-upgrade' <new version>
+#        * <conflictor's-postinst> `abort-remove' `in-favour' <package>
+#          <new-version>
+#        * <deconfigured's-postinst> `abort-deconfigure' `in-favour'
+#          <failed-install-package> <version> `removing'
+#          <conflicting-package> <version>
+# for details, see /usr/share/doc/packaging-manual/
+#
+# quoting from the policy:
+#     Any necessary prompting should almost always be confined to the
+#     post-installation script, and should be protected with a conditional
+#     so that unnecessary prompting doesn't happen if a package's
+#     installation fails and the `postinst' is called with `abort-upgrade',
+#     `abort-remove' or `abort-deconfigure'.
+
+case "$1" in
+    configure)
+
+    ;;
+
+    abort-upgrade|abort-remove|abort-deconfigure)
+
+    ;;
+
+    *)
+        echo "postinst called with unknown argument \`$1'" >&2
+        exit 0
+    ;;
+esac
+
+# dh_installdeb will replace this with shell code automatically
+# generated by other debhelper scripts.
+
+#DEBHELPER#
+
+exit 0
+
+
--- althea-ssl-0.5.5.orig/debian/postrm
+++ althea-ssl-0.5.5/debian/postrm
@@ -0,0 +1,36 @@
+#! /bin/sh
+# postrm script for althea
+#
+# see: dh_installdeb(1)
+
+set -e
+
+# summary of how this script can be called:
+#        * <postrm> `remove'
+#        * <postrm> `purge'
+#        * <old-postrm> `upgrade' <new-version>
+#        * <new-postrm> `failed-upgrade' <old-version>
+#        * <new-postrm> `abort-install'
+#        * <new-postrm> `abort-install' <old-version>
+#        * <new-postrm> `abort-upgrade' <old-version>
+#        * <disappearer's-postrm> `disappear' <r>overwrit>r> <new-version>
+# for details, see /usr/share/doc/packaging-manual/
+
+case "$1" in
+       purge|remove|upgrade|failed-upgrade|abort-install|abort-upgrade|disappear)
+
+
+        ;;
+
+    *)
+        echo "postrm called with unknown argument \`$1'" >&2
+        exit 0
+
+esac
+
+# dh_installdeb will replace this with shell code automatically
+# generated by other debhelper scripts.
+
+#DEBHELPER#
+
+
--- althea-ssl-0.5.5.orig/debian/preinst
+++ althea-ssl-0.5.5/debian/preinst
@@ -0,0 +1,42 @@
+#! /bin/sh
+# preinst script for althea
+#
+# see: dh_installdeb(1)
+
+set -e
+
+# summary of how this script can be called:
+#        * <new-preinst> `install'
+#        * <new-preinst> `install' <old-version>
+#        * <new-preinst> `upgrade' <old-version>
+#        * <old-preinst> `abort-upgrade' <new-version>
+#
+# For details see /usr/share/doc/packaging-manual/
+
+case "$1" in
+    install|upgrade)
+#        if [ "$1" = "upgrade" ]
+#        then
+#            start-stop-daemon --stop --quiet --oknodo  \
+#                --pidfile /var/run/althea.pid  \
+#                --exec /usr/sbin/althea 2>/dev/null || true
+#        fi
+    ;;
+
+    abort-upgrade)
+    ;;
+
+    *)
+        echo "preinst called with unknown argument \`$1'" >&2
+        exit 0
+    ;;
+esac
+
+# dh_installdeb will replace this with shell code automatically
+# generated by other debhelper scripts.
+
+#DEBHELPER#
+
+exit 0
+
+
--- althea-ssl-0.5.5.orig/debian/prerm
+++ althea-ssl-0.5.5/debian/prerm
@@ -0,0 +1,37 @@
+#! /bin/sh
+# prerm script for althea
+#
+# see: dh_installdeb(1)
+
+set -e
+
+# summary of how this script can be called:
+#        * <prerm> `remove'
+#        * <old-prerm> `upgrade' <new-version>
+#        * <new-prerm> `failed-upgrade' <old-version>
+#        * <conflictor's-prerm> `remove' `in-favour' <package> <new-version>
+#        * <deconfigured's-prerm> `deconfigure' `in-favour'
+#          <package-being-installed> <version> `removing'
+#          <conflicting-package> <version>
+# for details, see /usr/share/doc/packaging-manual/
+
+case "$1" in
+    remove|upgrade|deconfigure)
+#       install-info --quiet --remove /usr/info/althea.info.gz
+        ;;
+    failed-upgrade)
+        ;;
+    *)
+        echo "prerm called with unknown argument \`$1'" >&2
+        exit 0
+    ;;
+esac
+
+# dh_installdeb will replace this with shell code automatically
+# generated by other debhelper scripts.
+
+#DEBHELPER#
+
+exit 0
+
+
--- althea-ssl-0.5.5.orig/debian/watch
+++ althea-ssl-0.5.5/debian/watch
@@ -0,0 +1,4 @@
+# Watch control file for uscan
+# You can run the "uscan" command to check for upstream updates and more.
+# Site		Directory		Pattern			Version	Script
+http://ftp1.sourceforge.net	/althea	althea-(.*)\.tgz	debian	uupdate
--- althea-ssl-0.5.5.orig/debian/doc-base
+++ althea-ssl-0.5.5/debian/doc-base
@@ -0,0 +1,12 @@
+Document: althea
+Title: Althea Manual
+Author: Althea Developers
+Abstract: This manual describes how to use Althea, an
+ IMAP email client for GTK+.
+Section: Apps/Net
+
+Format: HTML
+Index: /usr/share/doc/althea-ssl/help.html
+Files: /usr/share/doc/althea-ssl/*.html
+
+  
--- althea-ssl-0.5.5.orig/debian/README.Debian
+++ althea-ssl-0.5.5/debian/README.Debian
@@ -0,0 +1,42 @@
+Althea for Debian
+-----------------
+
+SSL support is now disabled by default in the althea package and enabled by
+default in the althea-ssl package. If you have the source for the althea
+package and you want to generate the source for the althea-ssl package, first
+ensure that you have the patch program installed, and then change to the
+althea-V.E.R directory (where V.E.R is the current version number) and type
+'debian/rules select-ssl'. The althea-ssl tree will be generated parallel to
+the althea tree, and it should build cleanly with the usual Debian package
+building tools.
+
+To disable SSL support if you have the source for the althea-ssl package, edit
+the Makefile and change the block of lines that looks like this:
+
+#NOSSLFLAG = -DNOSSL
+#SSLFLAGS =
+SSLFLAGS = -lssl -lcrypto
+NOSSLFLAG =
+
+to look like this instead:
+
+NOSSLFLAG = -DNOSSL
+SSLFLAGS =
+#SSLFLAGS = -lssl -lcrypto
+#NOSSLFLAG =
+
+and then build the package. You may also wish to remove the Build-Depends on
+libssl-dev in the debian/control file, and/or change the Section field in the
+same file from non-US to mail. I have no opinion on the advisability of either
+change. This is incomplete advice though, since the package would still be
+named althea-ssl, and so would the directories within /usr/share and
+/usr/share/doc. The best thing to do if you do not want SSL support is to use
+the althea package.
+
+One other quick note: there can be a system-wide configuration file for
+Althea, which would reside at /etc/althearc. However since there are no
+reasonable defaults that I can think of, this file is not included in
+the package and would have to be added by the system administrator. There is,
+however, an althearc.example file in /usr/share/doc/althea(-ssl)/examples.
+
+Jimmy Kaplowitz <jimmy@debian.org>, Tue,  5 Jun 2001 11:28:33 -0400
--- althea-ssl-0.5.5.orig/debian/copyright
+++ althea-ssl-0.5.5/debian/copyright
@@ -0,0 +1,26 @@
+This package was debianized by Jimmy Kaplowitz <jimmy@kaplowitz.org> on
+Sat, 21 Apr 2001 21:28:55 -0400.
+
+It was downloaded from http://althea.sourceforge.net/ .
+
+Upstream Authors: various, reachable at althea-developers@lists.sourceforge.net
+
+Copyright:
+
+   This package is free software; you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation; version 2 dated June, 1991.
+
+   This package is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with this package; if not, write to the Free Software
+   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
+   02111-1307, USA.
+
+On Debian GNU/Linux systems, the complete text of the GNU General
+Public License can be found in `/usr/share/common-licenses/GPL'.
+
--- althea-ssl-0.5.5.orig/debian/enable-ssl-in-Makefile-patch
+++ althea-ssl-0.5.5/debian/enable-ssl-in-Makefile-patch
@@ -0,0 +1,30 @@
+--- Makefile.no-ssl	Mon Sep 24 22:29:58 2001
++++ Makefile	Mon Sep 24 22:30:58 2001
+@@ -49,11 +49,11 @@
+ 	  tolower.o \
+ 	  MIME.o
+ 
+-#comment the next two lines and uncomment the two after those...
+-NOSSLFLAG = -DNOSSL
+-SSLFLAGS =
+-#SSLFLAGS = -lssl -lcrypto
+-#NOSSLFLAG =
++#uncomment the next two lines and comment the two after those...
++#NOSSLFLAG = -DNOSSL
++#SSLFLAGS =
++SSLFLAGS = -lssl -lcrypto
++NOSSLFLAG =
+ 
+ 
+ PACKAGE=\"althea\"
+@@ -71,8 +71,8 @@
+ DESTDIR = /usr
+ 
+ BINDIR = ${DESTDIR}/bin
+-PIXDIR = ${DESTDIR}/share/althea
+-DOCDIR = ${DESTDIR}/share/doc/althea
++PIXDIR = ${DESTDIR}/share/althea-ssl
++DOCDIR = ${DESTDIR}/share/doc/althea-ssl
+ 
+ 
+ all : ${OBJS} 
--- althea-ssl-0.5.5.orig/debian/control.no-ssl
+++ althea-ssl-0.5.5/debian/control.no-ssl
@@ -0,0 +1,23 @@
+Source: althea
+Section: mail
+Priority: optional
+Maintainer: Jimmy Kaplowitz <jimmy@debian.org>
+Build-Depends: libglib1.2-dev (>= 1.2.0), libgtk1.2-dev (>= 1.2.0), debhelper (>> 3.0.0)
+Standards-Version: 3.5.6
+
+Package: althea
+Architecture: any
+Depends: ${shlibs:Depends}
+Provides: imap-client
+Description: IMAP email client for GTK+
+ The designers of Althea felt that there wasn't a stable, easy to use,
+ GUI, IMAP (Internet Message Access Protocol) e-mail client for X
+ Windows. The design goal was a stable e-mail client with the richness
+ of usability of Microsoft's Outlook, Qualcomm's Eudora, and Cyrusoft's
+ Mulberry.
+ .
+ This package was built without SSL support. If you want SSL support, use the
+ althea-ssl package, which is available in non-US, instead.
+ .
+ Check the documentation at /usr/share/doc/althea/help.html before filing
+ a bug report.
